diff cmake/Modules/FindSCTP.cmake @ 493:d68f27e7e814

Fixed a few CMake variable names
author Sebastien Decugis <sdecugis@nict.go.jp>
date Fri, 13 Aug 2010 17:23:39 +0900
parents 397cdcd41f53
children
line wrap: on
line diff
--- a/cmake/Modules/FindSCTP.cmake	Fri Aug 13 17:06:28 2010 +0900
+++ b/cmake/Modules/FindSCTP.cmake	Fri Aug 13 17:23:39 2010 +0900
@@ -2,12 +2,12 @@
 # Once done, this will define
 #
 #  SCTP_FOUND - system has SCTP
 #  SCTP_INCLUDE_DIRS - the SCTP include directories
 #  SCTP_LIBRARIES - link these to use SCTP
 
-if (SCTP_INCLUDE_DIRS AND SCTP_LIBRARIES)
+if (SCTP_INCLUDE_DIR AND SCTP_LIBRARIES)
   set(SCTP_FIND_QUIETLY TRUE)
-endif (SCTP_INCLUDE_DIRS AND SCTP_LIBRARIES)
+endif (SCTP_INCLUDE_DIR AND SCTP_LIBRARIES)
 
 # Include dir
 find_path(SCTP_INCLUDE_DIR
@@ -2,12 +2,12 @@
 #
 #  SCTP_FOUND - system has SCTP
-#  SCTP_INCLUDE_DIRS - the SCTP include directories
+#  SCTP_INCLUDE_DIR - the SCTP include directories
 #  SCTP_LIBRARIES - link these to use SCTP
 
"Welcome to our mercurial repository"